==> sight_21.1.1.orig.tar.gz: sight-21.1.1/libs/core/core/crypto/AES256.hpp <==
/************************************************************************
 *
 * Copyright (C) 2021 IRCAD France
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include "core/config.hpp"
#include "core/crypto/secure_string.hpp"

namespace sight::core::crypto
{

/// Decrypt a message using AES256 algorithm
/// @param message encrypted message
/// @param password password to use to decrypt the message
/// @returns decrypted message
CORE_API std::string decrypt(const std::string& message, const secure_string& password);
CORE_API secure_string decrypt(const secure_string& message, const secure_string& password);
CORE_API secure_string decrypt(const char* const message, const secure_string& password);

/// Encrypt a message using AES256 algorithm
/// @param message clear message
/// @param password password to use to encrypt the message
/// @returns encrypted message
CORE_API std::string encrypt(const std::string& message, const secure_string& password);
CORE_API secure_string encrypt(const secure_string& message, const secure_string& password);
CORE_API secure_string encrypt(const char* const message, const secure_string& password);

} // namespace sight::core::crypto

==> sight_23.1.0.orig.tar.gz: sight-23.1.0/libs/core/core/crypto/AES256.hpp <==
/************************************************************************
 *
 * Copyright (C) 2021-2022 IRCAD France
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include "core/config.hpp"
#include "core/crypto/secure_string.hpp"

namespace sight::core::crypto
{

/// Decrypt a message using AES256 algorithm
/// @param message encrypted message
/// @param password password to use to decrypt the message
/// @returns decrypted message
CORE_API std::string decrypt(const std::string& message, const secure_string& password);
CORE_API secure_string decrypt(const secure_string& message, const secure_string& password);
CORE_API secure_string decrypt(const char* message, const secure_string& password);

/// Encrypt a message using AES256 algorithm
/// @param message clear message
/// @param password password to use to encrypt the message
/// @returns encrypted message
CORE_API std::string encrypt(const std::string& message, const secure_string& password);
CORE_API secure_string encrypt(const secure_string& message, const secure_string& password);
CORE_API secure_string encrypt(const char* message, const secure_string& password);

} // namespace sight::core::crypto
